@@ -328,6 +328,16 @@ class SkipPartialQuery(PartialQuery):
         return f" SKIP {self.integer_expression} "
 
 
+class AddStringPartialQuery(PartialQuery):
+    def __init__(self, custom_cypher: str):
+        super().__init__(DeclarativeBaseTypes.SKIP)
+
+        self.custom_cypher = custom_cypher
+
+    def construct_query(self) -> str:
+        return f"{self.custom_cypher}"
+
+
 class DeclarativeBase(ABC):
     def __init__(self, connection: Optional[Union[Connection, Memgraph]] = None):
         self._query: List[Any] = []
@@ -492,6 +502,11 @@ class DeclarativeBase(ABC):
 
         return self
 
+    def add_custom_cypher(self, custom_cypher: str) -> "DeclarativeBase":
+        self._query.append(AddStringPartialQuery(custom_cypher))
+
+        return self
+
     def get_single(self, retrieve: str) -> Any:
         query = self._construct_query()
 
